from distutils.core import setup

setup (
	name		= 'time-sanitize',
	version		= '1.0.0',
	py_modules	= ['sanitize'],
	author		= 'tobypy16',
	author_email	= 'computerkid342@gmail.com',
	url		= 'linuxandbeyond.com',
	description	= 'A function that unifys different time formats (e.g, min:sec, min-sec, min.sec) to min.sec'
)
